@@ -1,7 +1,15 @@
+from typing import Any
+
+
 class TopicPartition:
     pass
 
 
+class Message:
+    offset: int
+    value: Any
+
+
 class ConsumerRebalanceListener:
     async def on_partitions_revoked(self, revoked: list[TopicPartition]) -> None:
         pass
@@ -22,6 +30,16 @@ class AIOKafkaConsumer:
     async def stop(self) -> None:
         pass
 
+    async def getmany(  # type: ignore
+        self,
+        timeout_ms: float,
+        max_records: int | None,
+    ) -> dict[TopicPartition, list[Message]]:
+        pass
+
+    async def commit(self, offsets: dict[TopicPartition, int]) -> None:
+        pass
+
 
 class KafkaError(Exception):
     pass
